@@ -2,6 +2,7 @@ package Sweet::File;
 use Moose;
 use namespace::autoclean;
 
+use Carp;
 use Try::Tiny;
 
 use File::Basename;
@@ -35,6 +36,18 @@ has dir => (
     predicate => 'has_dir',
 );
 
+sub _build_dir {
+    my $self = shift;
+
+    my $path = $self->path;
+
+    my $dirname = dirname($path);
+
+    my $dir = Sweet::Dir->new( path => $dirname );
+
+    return $dir;
+}
+
 has name => (
     builder   => '_build_name',
     is        => 'ro',
@@ -43,7 +56,17 @@ has name => (
     predicate => 'has_name',
 );
 
-has ext => (
+sub _build_name {
+    my $self = shift;
+
+    my $path = $self->path;
+
+    my $name = basename($path);
+
+    return $name;
+}
+
+has extension => (
     default => sub {
         my $path = shift->path;
 
@@ -54,13 +77,12 @@ has ext => (
     is        => 'ro',
     isa       => 'Str',
     lazy      => 1,
-    predicate => 'has_ext',
 );
 
 has path => (
     builder => '_build_path',
     coerce  => 1,
-    is      => 'rw',
+    is      => 'ro',
     isa     => 'Path::Class::File',
     lazy    => 1,
 );
@@ -84,11 +106,13 @@ sub copy_to_dir {
     my $dir  = shift;
     my $name = $self->name;
 
+    my $class = $self->meta->name;
+
     my $file_copied = try {
-        Sweet::File->new( dir => $dir, name => $name );
+        $class->new( dir => $dir, name => $name );
     }
     catch {
-        die $_;
+        confess $_;
     };
 
     my $source_path = $self->path;
@@ -98,14 +122,14 @@ sub copy_to_dir {
         $dir->is_a_directory or $dir->create;
     }
     catch {
-        die $_;
+        confess $_;
     };
 
     try {
         copy( $source_path, $target_path );
     }
     catch {
-        die $_;
+        confess $_;
     };
 
     return $file_copied;
@@ -131,8 +155,6 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
-=encoding utf8
-
 =head1 NAME
 
 Sweet::File
@@ -141,16 +163,18 @@ Sweet::File
 
     use Sweet::File;
 
-    my $file = Sweet::File->new(
+    my $file1 = Sweet::File->new(
         dir => '/path/to/dir',
         name => 'foo',
     );
 
+    my $file2 = Sweet::File->new(path => '/path/to/file');
+
 =head1 ATTRIBUTES
 
 =head2 dir
 
-=head2 ext
+=head2 extension
 
 =head2 name
 
