@@ -4,7 +4,7 @@ use namespace::autoclean;
 
 extends 'Sweet::File::DSV';
 
-sub _build_sep { ',' }
+sub _build_separator { ',' }
 
 __PACKAGE__->meta->make_immutable;
 
@@ -18,6 +18,10 @@ Sweet::File::CSV
 
     my $csv = Sweet::File::CSV->new(dir => $dir, name => 'file.csv');
 
+=head1 INHERITANCE
+
+Inherits from C<Sweet::File::DSV>.
+
 =head1 ATTRIBUTES
 
 =head2 sep
